# encoding: UTF-8
desc "Recreates epochs cache"
task :recreate_epoch_cache do 
  Transfer.each{|t| t.epoch_id = t.epoch.id; t.save }
end
  
desc "Cleans Amounts and Split table"
task :cleanup => :environment do 
  report_and_destroy("amounts with void splits", Amount.where("split_id =''"))
  report_and_destroy('splits with void transfer',Split.where("transfer_id =''"))
  report_and_destroy('splits without transfers', Split.joins{transfer.outer}.where{transfer.id == nil})
  report_and_destroy('amounts without splits',   Amount.joins{split.outer}.where{split.id == nil})
  Transfer.all{ |t| 
    if t.splits.size!=2
      puts "Transfer #{t.id} '#{t.popis}' nemá řádné splity!"
    end
  }
end

def report_and_destroy(popis, rel)
  count = rel.count
  mess = "There are #{count} #{popis}."
  if count==0
    puts "#{mess} OK."
  else
    puts "#{mess} ==> destroying"
    rel.destroy_all
    puts "After destroy #{rel.count} remained. "
  end
end

desc "Normalizuje vendory podle normalizační tabulky, momentálně hermany"
task :normalize_vendors => :environment do 
  normalization_array = {
    'Petr'=>'Petr Holub',
    'Alča'=>'Alča Válková',
    'alča'=>'Alča Válková',
    'bobo'=>'Bobo Kebza',
    'Bobo'=>'Bobo Kebza',
    'dan'=>'Dan Zeman',
    'Dan'=>'Dan Zeman',
    'Ilča'=>'Ilča Pašková',
    'ilča'=>'Ilča Pašková',
    'Jakub'=>'Jakub Těšínský',
    'jakub'=>'Jakub Těšínský',
    'jakub Těšínský'=>'Jakub Těšínský',
    'Vidlička'=>'Martin Diviš',
    'vidlička'=>'Martin Diviš',
    'Marti Diviš'=>'Martin Diviš',
    'Dědek'=>'Matěj Baťha',
    'dědek'=>'Matěj Baťha',
    'Karel'=>'Karel Nejedlík',
    'karel'=>'Karel Nejedlík',
    'Janča'=>'Janča Růžičková',
    'Miloš'=>'Miloš Dubský',
    'miloš'=>'Miloš Dubský',
    'johanka'=>'Johana Pavelková',
    'Johanka'=>'Johana Pavelková',
    'Klára'=>'Klára Zemanová',
    'klára'=>'Klára Zemanová',
    'Šípák'=>'Milan Šíp',
    'šípák'=>'Milan Šíp',
    'Šíp'=>'Milan Šíp',
    'Milan'=>'Milan Šíp',
    'Kamil'=>'Kamil Jeřábek',
    'kamil'=>'Kamil Jeřábek',
    'Honza'=>'Honza Bartoš',
    'honza'=>'Honza Bartoš',
    'Marián Klimek'=>'Marian Klimek',
    'mafian'=>'Marian Klimek',
    'marian'=>'Marian Klimek',
    'Mafian'=>'Marian Klimek',
    'Marian'=>'Marian Klimek',
    'Martin Č'=>'Martin Čepelík',
    'martina'=>'Martina Bílková',
    'Martina'=>'Martina Bílková',
    'martin marek'=>'Martin Marek',
    'mikuláš'=>'Mikuláš Hvězda',
    'Mikuláš'=>'Mikuláš Hvězda',
    'miloš'=>'Miloš Dubský',
    'Petr S.'=>'Petr Sedláček',
    'Radka'=>'Radka Lomičková',
    'radka'=>'Radka Lomičková',
    'Richard'=>'Richard Forst',
    'richard'=>'Richard Forst',
    'tonda'=>'Tonda Mocek',
    'Vlasta'=>'Vlasta Peksa',
    'hraboš'=>'Vojtěch Hrabal',
    'Hraboš'=>'Vojtěch Hrabal',
    'Hrabosh'=>'Vojtěch Hrabal',
    'Tonda'=>'Tonda Mocek',
    'Petra B.'=>'Petra Bidlasová',
    'Fuxinda'=>'Petra Fuksová',
    'fuxinda'=>'Petra Fuksová',
    'Lenka'=>'Lenka Vokatá',
    'Plotík'=>'Marek Šimon',
    'Pletiplot'=>'Marek Šimon',
    'plotík'=>'Marek Šimon',
    'herman(ka)'=>'Neznámý',
    '0.0'=>'Neznámý',
    'NEZNÁMÝ HERMAN'=>'Neznámý',
    'herman(ka)'=>'Neznámý',
     'Vítek'=>'Vítek Vodička',
    'ester'=>'Ester Francová',
    'eva'=>'Eva',
    'herman'=>'Neznámý',
    'lenka'=>'Lenka Vokatá',
    'ondra'=>'Ondra Šnajdr',
    'Ondra'=>'Ondra Šnajdr',
    'Obdra Šnajdr'=>'Ondra Šnajdr',
    'pepa'=>'Pepa',
    'petr'=>'Petr Holub',
    'Trohat'=>'Petr Sedláček',
    'petra'=>'Petra',
    'Pogo'=>'Pavel Prachař',
    'pogo'=>'Pavel Prachař',
    'tomáš'=>'Tomáš',
    'vítek'=>'Vítek Vodička'
#    ''=>'',
  }
  a = Account.find('3d3ac2da-669e-11df-9fa9-0013d4bc1a7d')  # Paluba # Hermanské dluhy
  normalization_array.each_pair { |source,target|
    transfers = a.transfers.select{|t| t.vendor == source}
    puts "#{source} => #{target} #{transfers.size}x"
    if transfers.size>0
      transfers.each{|t|
        t.vendor=target
        t.save
      }
    end
  }
end

namespace :switch do
  task :constants => :environment do
    @filename = APACHE_CONFIG_FILE
    require Rails.root.join('config','initializers','constants.rb')
    @siteurl = SITE_URL.gsub(/http:\/*|\/$/,'')
    @modes = ['development','production']
  end

  task :development => :constants do
    switch_to('development')
  end
  
  task :production => :constants do
    switch_to('production')
  end
  
  task :production_full => [:precompile_assets, :production]
  
  task :precompile_assets do
    system 'bundle exec rake assets:precompile'
  end
  
  task :d => :development
  task :p => :production
  
  def switch_to(mode)
    text = File.read(@filename)
    @modes.each{ |m| text = disable_mode_in(m,text) } # disable all
    text = enable_mode_in(mode,text)                  # enable desired
    File.open(@filename, "w") { |file| file << text }
    system 'sudo /etc/init.d/apache2 restart'
  end
  
  def disable_mode_in(mode,text)
    text.gsub(/\n#\s*#{@siteurl}\s*switchline\s*\n\s*(?=(RackEnv|RailsEnv)\s*#{mode})/, "\n# #{@siteurl} switchline\n# ")
  end
  def enable_mode_in(mode,text)
    text.gsub(/\n#\s*#{@siteurl}\s*switchline\s*\n\s*#\s*(?=(RackEnv|RailsEnv)\s*#{mode})/, "\n# #{@siteurl} switchline\n ")
  end
end






















